@@ -71,7 +71,7 @@ class RundeckJobs(object):
             uptimerobot_api_key: str = os.environ.get(
                 "RD_OPTION_UPTIMEROBOT_API_KEY"),
             fqdn: str = os.environ.get("RD_OPTION_FQDN"),
-            force_apply: bool = os.environ.get('RD_OPTION_FORCE_APPLY')):
+            force_apply: str = os.environ.get('RD_OPTION_FORCE_APPLY')):
         if deployment_action != 'apply':
             print("Skipping website hosting check as deployment action is not apply")
             exit(0)
@@ -87,11 +87,10 @@ class RundeckJobs(object):
         matched_monitors = [response.json()['monitors'][i]['friendly_name'] for i in range(len(
             response.json()['monitors'])) if response.json()['monitors'][i]['friendly_name'] == fqdn]
 
-        print((type(force_apply)))
         if not matched_monitors:
             print(f"{fqdn} seems to be a new site, skipping!")
             exit(0)
-        elif force_apply:
+        elif force_apply == 'true':
             print("Force apply is requested, ignoring check results")
             exit(0)
         else:
